==> ICUSIM-0.0.2.tar.gz: ICUSIM-0.0.2/setup.py <==
#! /usr/bin/env python

DESCRIPTION = "Intensive Care Unit (ICU) Simulation"
LONG_DESCRIPTION = """\
ICUSIM simplifies the process of simulating ICU burden scenarios
based on rich set of input variables.
"""

DISTNAME = 'ICUSIM'
MAINTAINER = 'Mikko Kotila'
MAINTAINER_EMAIL = 'mailme@mikkokotila.com'
URL = 'http://autonom.io'
LICENSE = 'MIT'
DOWNLOAD_URL = 'https://github.com/autonomio/ICUSIM/'
VERSION = '0.0.2'

try:
    from setuptools import setup
    _has_setuptools = True
except ImportError:
    from distutils.core import setup

install_requires = ['simpy==3.0.12',
                    'numpy',
                    'pandas',
                    'tqdm']

if __name__ == "__main__":

    setup(name=DISTNAME,
          author=MAINTAINER,
          author_email=MAINTAINER_EMAIL,
          maintainer=MAINTAINER,
          maintainer_email=MAINTAINER_EMAIL,
          description=DESCRIPTION,
          long_description=LONG_DESCRIPTION,
          license=LICENSE,
          url=URL,
          version=VERSION,
          download_url=DOWNLOAD_URL,
          install_requires=install_requires,
          packages=['icusim'],

          classifiers=['Intended Audience :: Science/Research',
                       'Programming Language :: Python :: 3.5',
                       'Programming Language :: Python :: 3.6',
                       'License :: OSI Approved :: MIT License',
                       'Topic :: Scientific/Engineering :: Human Machine Interfaces',
                       'Topic :: Scientific/Engineering :: Mathematics',
                       'Operating System :: POSIX',
                       'Operating System :: Unix',
                       'Operating System :: MacOS',
                       'Operating System :: Microsoft :: Windows :: Windows 10'])

==> ICUSIM-0.2.0.tar.gz: ICUSIM-0.2.0/setup.py <==
#! /usr/bin/env python

DESCRIPTION = "Intensive Care Unit (ICU) Simulation"
LONG_DESCRIPTION = """\
ICUSIM simplifies the process of simulating ICU burden scenarios
based on rich set of input variables.
"""

DISTNAME = 'ICUSIM'
MAINTAINER = 'Mikko Kotila'
MAINTAINER_EMAIL = 'mailme@mikkokotila.com'
URL = 'http://autonom.io'
LICENSE = 'MIT'
DOWNLOAD_URL = 'https://github.com/autonomio/ICUSIM/'
VERSION = '0.2.0'

try:
    from setuptools import setup
    _has_setuptools = True
except ImportError:
    from distutils.core import setup

install_requires = ['simpy==3.0.12',
                    'numpy',
                    'pandas',
                    'tqdm',
                    'salib']

if __name__ == "__main__":

    setup(name=DISTNAME,
          author=MAINTAINER,
          author_email=MAINTAINER_EMAIL,
          maintainer=MAINTAINER,
          maintainer_email=MAINTAINER_EMAIL,
          description=DESCRIPTION,
          long_description=LONG_DESCRIPTION,
          license=LICENSE,
          url=URL,
          version=VERSION,
          download_url=DOWNLOAD_URL,
          install_requires=install_requires,
          packages=['icusim', 'icusim.commands'],

          classifiers=['Intended Audience :: Science/Research',
                       'Programming Language :: Python :: 3.5',
                       'Programming Language :: Python :: 3.6',
                       'License :: OSI Approved :: MIT License',
                       'Topic :: Scientific/Engineering :: Human Machine Interfaces',
                       'Topic :: Scientific/Engineering :: Mathematics',
                       'Operating System :: POSIX',
                       'Operating System :: Unix',
                       'Operating System :: MacOS',
                       'Operating System :: Microsoft :: Windows :: Windows 10'])
